# SciERC

**EMNLP 2018**: [Multi-Task Identification of Entities, Relations, and Coreference for Scientific Knowledge Graph Construction](https://aclanthology.org/D18-1360/)

[**Website**](https://nlp.cs.washington.edu/sciIE/)

[**Annotation Guideline**](https://nlp.cs.washington.edu/sciIE/annotation_guideline.pdf)

## Errata

We hard-code corrections to the following errata:

1. In the training sample `H05-1117`, the mention `[106, 106]` is repeated in its cluster.
